@@ -107,6 +107,12 @@ class BOTAN_PUBLIC_API(2,0) EC_Group final
 
       ~EC_Group();
 
+      EC_Group(const EC_Group&) = default;
+      EC_Group(EC_Group&&) = default;
+
+      EC_Group& operator=(const EC_Group&) = default;
+      EC_Group& operator=(EC_Group&&) = default;
+
       /**
       * Create the DER encoding of this domain
       * @param form of encoding to use
